==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/SharedDriveItem.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.complex.IdentitySet;
import odata.msgraph.client.beta.complex.ItemReference;
import odata.msgraph.client.beta.entity.collection.request.DriveItemCollectionRequest;
import odata.msgraph.client.beta.entity.request.DriveItemRequest;
import odata.msgraph.client.beta.entity.request.ListItemRequest;
import odata.msgraph.client.beta.entity.request.ListRequest;
import odata.msgraph.client.beta.entity.request.PermissionRequest;
import odata.msgraph.client.beta.entity.request.SiteRequest;

@JsonPropertyOrder({
    "@odata.type", 
    "owner"})
@JsonInclude(Include.NON_NULL)
public class SharedDriveItem extends BaseItem implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.sharedDriveItem";
    }

    @JsonProperty("owner")
    protected IdentitySet owner;

    protected SharedDriveItem() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderSharedDriveItem() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private IdentitySet createdBy;
        private OffsetDateTime createdDateTime;
        private String description;
        private String eTag;
        private IdentitySet lastModifiedBy;
        private OffsetDateTime lastModifiedDateTime;
        private String name;
        private ItemReference parentReference;
        private String webUrl;
        private IdentitySet owner;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder createdBy(IdentitySet createdBy) {
            this.createdBy = createdBy;
            this.changedFields = changedFields.add("createdBy");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public Builder eTag(String eTag) {
            this.eTag = eTag;
            this.changedFields = changedFields.add("eTag");
            return this;
        }

        public Builder lastModifiedBy(IdentitySet lastModifiedBy) {
            this.lastModifiedBy = lastModifiedBy;
            this.changedFields = changedFields.add("lastModifiedBy");
            return this;
        }

        public Builder lastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
            this.lastModifiedDateTime = lastModifiedDateTime;
            this.changedFields = changedFields.add("lastModifiedDateTime");
            return this;
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder parentReference(ItemReference parentReference) {
            this.parentReference = parentReference;
            this.changedFields = changedFields.add("parentReference");
            return this;
        }

        public Builder webUrl(String webUrl) {
            this.webUrl = webUrl;
            this.changedFields = changedFields.add("webUrl");
            return this;
        }

        public Builder owner(IdentitySet owner) {
            this.owner = owner;
            this.changedFields = changedFields.add("owner");
            return this;
        }

        public SharedDriveItem build() {
            SharedDriveItem _x = new SharedDriveItem();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.sharedDriveItem";
            _x.id = id;
            _x.createdBy = createdBy;
            _x.createdDateTime = createdDateTime;
            _x.description = description;
            _x.eTag = eTag;
            _x.lastModifiedBy = lastModifiedBy;
            _x.lastModifiedDateTime = lastModifiedDateTime;
            _x.name = name;
            _x.parentReference = parentReference;
            _x.webUrl = webUrl;
            _x.owner = owner;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="owner")
    @JsonIgnore
    public Optional<IdentitySet> getOwner() {
        return Optional.ofNullable(owner);
    }

    public SharedDriveItem withOwner(IdentitySet owner) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("owner");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.owner = owner;
        return _x;
    }

    @NavigationProperty(name="driveItem")
    @JsonIgnore
    public DriveItemRequest getDriveItem() {
        return new DriveItemRequest(contextPath.addSegment("driveItem"));
    }

    @NavigationProperty(name="items")
    @JsonIgnore
    public DriveItemCollectionRequest getItems() {
        return new DriveItemCollectionRequest(
                        contextPath.addSegment("items"));
    }

    @NavigationProperty(name="list")
    @JsonIgnore
    public ListRequest getList() {
        return new ListRequest(contextPath.addSegment("list"));
    }

    @NavigationProperty(name="listItem")
    @JsonIgnore
    public ListItemRequest getListItem() {
        return new ListItemRequest(contextPath.addSegment("listItem"));
    }

    @NavigationProperty(name="permission")
    @JsonIgnore
    public PermissionRequest getPermission() {
        return new PermissionRequest(contextPath.addSegment("permission"));
    }

    @NavigationProperty(name="root")
    @JsonIgnore
    public DriveItemRequest getRoot() {
        return new DriveItemRequest(contextPath.addSegment("root"));
    }

    @NavigationProperty(name="site")
    @JsonIgnore
    public SiteRequest getSite() {
        return new SiteRequest(contextPath.addSegment("site"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public SharedDriveItem patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        SharedDriveItem _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public SharedDriveItem put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        SharedDriveItem _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private SharedDriveItem _copy() {
        SharedDriveItem _x = new SharedDriveItem();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.createdBy = createdBy;
        _x.createdDateTime = createdDateTime;
        _x.description = description;
        _x.eTag = eTag;
        _x.lastModifiedBy = lastModifiedBy;
        _x.lastModifiedDateTime = lastModifiedDateTime;
        _x.name = name;
        _x.parentReference = parentReference;
        _x.webUrl = webUrl;
        _x.owner = owner;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SharedDriveItem[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("createdBy=");
        b.append(this.createdBy);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("description=");
        b.append(this.description);
        b.append(", ");
        b.append("eTag=");
        b.append(this.eTag);
        b.append(", ");
        b.append("lastModifiedBy=");
        b.append(this.lastModifiedBy);
        b.append(", ");
        b.append("lastModifiedDateTime=");
        b.append(this.lastModifiedDateTime);
        b.append(", ");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("parentReference=");
        b.append(this.parentReference);
        b.append(", ");
        b.append("webUrl=");
        b.append(this.webUrl);
        b.append(", ");
        b.append("owner=");
        b.append(this.owner);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/SharedDriveItem.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.IdentitySet;
import odata.msgraph.client.beta.complex.ItemReference;
import odata.msgraph.client.beta.entity.collection.request.DriveItemCollectionRequest;
import odata.msgraph.client.beta.entity.request.DriveItemRequest;
import odata.msgraph.client.beta.entity.request.ListItemRequest;
import odata.msgraph.client.beta.entity.request.ListRequest;
import odata.msgraph.client.beta.entity.request.PermissionRequest;
import odata.msgraph.client.beta.entity.request.SiteRequest;

@JsonPropertyOrder({
    "@odata.type", 
    "owner", 
    "driveItem", 
    "items", 
    "list", 
    "listItem", 
    "permission", 
    "root", 
    "site"})
@JsonInclude(Include.NON_NULL)
public class SharedDriveItem extends BaseItem implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.sharedDriveItem";
    }

    @JsonProperty("owner")
    protected IdentitySet owner;

    @JsonProperty("driveItem")
    protected DriveItem driveItem;

    @JsonProperty("items")
    protected List<DriveItem> items;

    @JsonProperty("list")
    protected odata.msgraph.client.beta.entity.List list;

    @JsonProperty("listItem")
    protected ListItem listItem;

    @JsonProperty("permission")
    protected Permission permission;

    @JsonProperty("root")
    protected DriveItem root;

    @JsonProperty("site")
    protected Site site;

    protected SharedDriveItem() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderSharedDriveItem() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private IdentitySet createdBy;
        private OffsetDateTime createdDateTime;
        private String description;
        private String eTag;
        private IdentitySet lastModifiedBy;
        private OffsetDateTime lastModifiedDateTime;
        private String name;
        private ItemReference parentReference;
        private String webUrl;
        private IdentitySet owner;
        private DriveItem driveItem;
        private List<DriveItem> items;
        private odata.msgraph.client.beta.entity.List list;
        private ListItem listItem;
        private Permission permission;
        private DriveItem root;
        private Site site;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder createdBy(IdentitySet createdBy) {
            this.createdBy = createdBy;
            this.changedFields = changedFields.add("createdBy");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public Builder eTag(String eTag) {
            this.eTag = eTag;
            this.changedFields = changedFields.add("eTag");
            return this;
        }

        public Builder lastModifiedBy(IdentitySet lastModifiedBy) {
            this.lastModifiedBy = lastModifiedBy;
            this.changedFields = changedFields.add("lastModifiedBy");
            return this;
        }

        public Builder lastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
            this.lastModifiedDateTime = lastModifiedDateTime;
            this.changedFields = changedFields.add("lastModifiedDateTime");
            return this;
        }

        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public Builder parentReference(ItemReference parentReference) {
            this.parentReference = parentReference;
            this.changedFields = changedFields.add("parentReference");
            return this;
        }

        public Builder webUrl(String webUrl) {
            this.webUrl = webUrl;
            this.changedFields = changedFields.add("webUrl");
            return this;
        }

        public Builder owner(IdentitySet owner) {
            this.owner = owner;
            this.changedFields = changedFields.add("owner");
            return this;
        }

        public Builder driveItem(DriveItem driveItem) {
            this.driveItem = driveItem;
            this.changedFields = changedFields.add("driveItem");
            return this;
        }

        public Builder items(List<DriveItem> items) {
            this.items = items;
            this.changedFields = changedFields.add("items");
            return this;
        }

        public Builder items(DriveItem... items) {
            return items(Arrays.asList(items));
        }

        public Builder list(odata.msgraph.client.beta.entity.List list) {
            this.list = list;
            this.changedFields = changedFields.add("list");
            return this;
        }

        public Builder listItem(ListItem listItem) {
            this.listItem = listItem;
            this.changedFields = changedFields.add("listItem");
            return this;
        }

        public Builder permission(Permission permission) {
            this.permission = permission;
            this.changedFields = changedFields.add("permission");
            return this;
        }

        public Builder root(DriveItem root) {
            this.root = root;
            this.changedFields = changedFields.add("root");
            return this;
        }

        public Builder site(Site site) {
            this.site = site;
            this.changedFields = changedFields.add("site");
            return this;
        }

        public SharedDriveItem build() {
            SharedDriveItem _x = new SharedDriveItem();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.sharedDriveItem";
            _x.id = id;
            _x.createdBy = createdBy;
            _x.createdDateTime = createdDateTime;
            _x.description = description;
            _x.eTag = eTag;
            _x.lastModifiedBy = lastModifiedBy;
            _x.lastModifiedDateTime = lastModifiedDateTime;
            _x.name = name;
            _x.parentReference = parentReference;
            _x.webUrl = webUrl;
            _x.owner = owner;
            _x.driveItem = driveItem;
            _x.items = items;
            _x.list = list;
            _x.listItem = listItem;
            _x.permission = permission;
            _x.root = root;
            _x.site = site;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="owner")
    @JsonIgnore
    public Optional<IdentitySet> getOwner() {
        return Optional.ofNullable(owner);
    }

    public SharedDriveItem withOwner(IdentitySet owner) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("owner");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.owner = owner;
        return _x;
    }

    public SharedDriveItem withUnmappedField(String name, Object value) {
        SharedDriveItem _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @NavigationProperty(name="driveItem")
    @JsonIgnore
    public DriveItemRequest getDriveItem() {
        return new DriveItemRequest(contextPath.addSegment("driveItem"), Optional.ofNullable(driveItem));
    }

    @NavigationProperty(name="items")
    @JsonIgnore
    public DriveItemCollectionRequest getItems() {
        return new DriveItemCollectionRequest(
                        contextPath.addSegment("items"), Optional.ofNullable(items));
    }

    @NavigationProperty(name="list")
    @JsonIgnore
    public ListRequest getList() {
        return new ListRequest(contextPath.addSegment("list"), Optional.ofNullable(list));
    }

    @NavigationProperty(name="listItem")
    @JsonIgnore
    public ListItemRequest getListItem() {
        return new ListItemRequest(contextPath.addSegment("listItem"), Optional.ofNullable(listItem));
    }

    @NavigationProperty(name="permission")
    @JsonIgnore
    public PermissionRequest getPermission() {
        return new PermissionRequest(contextPath.addSegment("permission"), Optional.ofNullable(permission));
    }

    @NavigationProperty(name="root")
    @JsonIgnore
    public DriveItemRequest getRoot() {
        return new DriveItemRequest(contextPath.addSegment("root"), Optional.ofNullable(root));
    }

    @NavigationProperty(name="site")
    @JsonIgnore
    public SiteRequest getSite() {
        return new SiteRequest(contextPath.addSegment("site"), Optional.ofNullable(site));
    }

    public SharedDriveItem withDriveItem(DriveItem driveItem) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("driveItem");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.driveItem = driveItem;
        return _x;
    }

    public SharedDriveItem withItems(List<DriveItem> items) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("items");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.items = items;
        return _x;
    }

    public SharedDriveItem withList(odata.msgraph.client.beta.entity.List list) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("list");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.list = list;
        return _x;
    }

    public SharedDriveItem withListItem(ListItem listItem) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("listItem");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.listItem = listItem;
        return _x;
    }

    public SharedDriveItem withPermission(Permission permission) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("permission");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.permission = permission;
        return _x;
    }

    public SharedDriveItem withRoot(DriveItem root) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("root");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.root = root;
        return _x;
    }

    public SharedDriveItem withSite(Site site) {
        SharedDriveItem _x = _copy();
        _x.changedFields = changedFields.add("site");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.sharedDriveItem");
        _x.site = site;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public SharedDriveItem patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        SharedDriveItem _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public SharedDriveItem put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        SharedDriveItem _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private SharedDriveItem _copy() {
        SharedDriveItem _x = new SharedDriveItem();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.createdBy = createdBy;
        _x.createdDateTime = createdDateTime;
        _x.description = description;
        _x.eTag = eTag;
        _x.lastModifiedBy = lastModifiedBy;
        _x.lastModifiedDateTime = lastModifiedDateTime;
        _x.name = name;
        _x.parentReference = parentReference;
        _x.webUrl = webUrl;
        _x.owner = owner;
        _x.driveItem = driveItem;
        _x.items = items;
        _x.list = list;
        _x.listItem = listItem;
        _x.permission = permission;
        _x.root = root;
        _x.site = site;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SharedDriveItem[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("createdBy=");
        b.append(this.createdBy);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("description=");
        b.append(this.description);
        b.append(", ");
        b.append("eTag=");
        b.append(this.eTag);
        b.append(", ");
        b.append("lastModifiedBy=");
        b.append(this.lastModifiedBy);
        b.append(", ");
        b.append("lastModifiedDateTime=");
        b.append(this.lastModifiedDateTime);
        b.append(", ");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("parentReference=");
        b.append(this.parentReference);
        b.append(", ");
        b.append("webUrl=");
        b.append(this.webUrl);
        b.append(", ");
        b.append("owner=");
        b.append(this.owner);
        b.append(", ");
        b.append("driveItem=");
        b.append(this.driveItem);
        b.append(", ");
        b.append("items=");
        b.append(this.items);
        b.append(", ");
        b.append("list=");
        b.append(this.list);
        b.append(", ");
        b.append("listItem=");
        b.append(this.listItem);
        b.append(", ");
        b.append("permission=");
        b.append(this.permission);
        b.append(", ");
        b.append("root=");
        b.append(this.root);
        b.append(", ");
        b.append("site=");
        b.append(this.site);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
